# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"display": "00_core.ipynb",
         "Markdown": "00_core.ipynb",
         "Audio": "00_core.ipynb",
         "explore": "00_core.ipynb",
         "is_jupyter": "00_core.ipynb",
         "async_get_responses": "00_core.ipynb",
         "beep": "00_core.ipynb",
         "fig": "00_core.ipynb",
         "h1": "00_core.ipynb",
         "h2": "00_core.ipynb",
         "h3": "00_core.ipynb",
         "h4": "00_core.ipynb",
         "h5": "00_core.ipynb",
         "h6": "00_core.ipynb",
         "from_file": "00_core.ipynb",
         "good_url": "00_core.ipynb",
         "user_agent": "00_core.ipynb",
         "extract_apex": "00_core.ipynb",
         "extract_meta_link": "00_core.ipynb",
         "extract_links": "00_core.ipynb",
         "extract_title": "00_core.ipynb",
         "extract_meta": "00_core.ipynb",
         "extract_hx": "00_core.ipynb",
         "extract_body": "00_core.ipynb",
         "extract_stemmed": "00_core.ipynb",
         "extract_url_keywords": "00_core.ipynb",
         "extract_keywords": "00_core.ipynb",
         "gsc_guess_site": "00_core.ipynb",
         "gsc_url2keyword_query": "00_core.ipynb",
         "gsc_url_query": "00_core.ipynb",
         "gsc2df": "00_core.ipynb",
         "df_allout": "00_core.ipynb",
         "ga_accounts": "00_core.ipynb",
         "ga_properties": "00_core.ipynb",
         "ga_properties_g4": "00_core.ipynb",
         "ga_profiles": "00_core.ipynb",
         "ga_everything": "00_core.ipynb",
         "inspect_url": "00_core.ipynb",
         "drop_table": "00_core.ipynb",
         "pk_compositor": "00_core.ipynb",
         "pk_inserter": "00_core.ipynb",
         "config2dict": "00_core.ipynb",
         "build_google_search_query": "00_core.ipynb",
         "extract_serps": "00_core.ipynb",
         "chrome": "00_core.ipynb",
         "run_me": "00_core.ipynb",
         "bs": "00_core.ipynb",
         "lr": "00_core.ipynb",
         "SPACES": "00_core.ipynb",
         "pstem": "00_core.ipynb",
         "stop_words": "00_core.ipynb",
         "pkl": "00_core.ipynb",
         "unpkl": "00_core.ipynb",
         "svc_ga": "00_core.ipynb",
         "svc_ga4": "00_core.ipynb",
         "svc_gsc": "00_core.ipynb",
         "svc_mail": "00_core.ipynb",
         "svc_oauth": "00_core.ipynb",
         "svc_sheet": "00_core.ipynb",
         "svc_photo": "00_core.ipynb",
         "svc_youtube": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://miklevin.github.io/mlseo/"

git_url = "https://github.com/miklevin/mlseo/tree/main/"

def custom_doc_links(name): return None
